use actix_web::{http::header::LOCATION, web, HttpResponse, Responder};
use serde::Deserialize;
use sqlx::PgPool;

use crate::models::{Area, Role, User};

#[derive(Deserialize)]
struct NewAreaForm {
    name: String,
}

#[actix_web::post("/area/new")]
pub async fn post(
    user: web::ReqData<User>,
    pool: web::Data<PgPool>,
    form: web::Form<NewAreaForm>,
) -> impl Responder {
    if user.role != Role::Admin {
        return HttpResponse::Unauthorized().finish();
    }

    match Area::create(pool.get_ref(), &form.name).await {
        Ok(_) => {
            return HttpResponse::Found()
                .insert_header((LOCATION, "/locations"))
                .insert_header(("HX-LOCATION", "/locations"))
                .finish()
        }
        Err(err) => {
            println!("{}", err);
            return HttpResponse::InternalServerError().finish();
        }
    }
}
