use actix_web::{http::header::LOCATION, web, HttpResponse, Responder};
use serde::Deserialize;
use sqlx::PgPool;

use crate::models::{Location, Role, User};

#[derive(Deserialize)]
pub struct NewLocationForm {
    name: String,
    area: Option<i32>,
}

#[actix_web::post("/locations/new")]
pub async fn post(
    user: web::ReqData<User>,
    pool: web::Data<PgPool>,
    form: web::Form<NewLocationForm>,
) -> impl Responder {

    if user.role == Role::AreaManager || user.role == Role::Admin {
        let mut area_id = user.area_id;

        if user.role == Role::Admin && form.area.is_some() {
            area_id = form.area.unwrap();
        }

        match Location::create(pool.get_ref(), &form.name, area_id).await {
            Ok(_) => {
                return HttpResponse::Found()
                    .insert_header((LOCATION, "/locations"))
                    .insert_header(("HX-LOCATION", "/locations"))
                    .finish()
            }
            Err(err) => {
                println!("{}", err);
                return HttpResponse::InternalServerError().finish();
            }
        }
    }

    return HttpResponse::Unauthorized().finish();
}
