use std::env;

use lettre::{
    transport::smtp::{authentication::Credentials, extension::ClientId},
    SmtpTransport,
};

pub fn get_mailer() -> anyhow::Result<SmtpTransport> {
    let server = &env::var("SMTP_SERVER")?;
    let port = &env::var("SMTP_PORT")?.parse()?;
    let login = &env::var("SMTP_LOGIN")
        .and_then(|x| Ok(Some(x)))
        .unwrap_or(None);
    let password = &env::var("SMTP_PASSWORD")
        .and_then(|x| Ok(Some(x)))
        .unwrap_or(None);
    let tls_type = &env::var("SMTP_TLSTYPE")?;
    let hostname = &env::var("HOSTNAME")?;

    let mut builder = match tls_type.as_str() {
        "starttls" => SmtpTransport::starttls_relay(server)?.port(*port),
        "tls" => SmtpTransport::relay(server)?.port(*port),
        _ => SmtpTransport::builder_dangerous(server).port(*port),
    };

    if let (Some(login), Some(password)) = (login, password) {
        builder = builder.credentials(Credentials::new(login.to_string(), password.to_string()));
    }

    let mailer = builder
        .hello_name(ClientId::Domain(hostname.to_string()))
        .build();

    Ok(mailer)
}
